#
# ADNI_Application_Wrapper.R
#
# This is a wrapper file that executes the necessary scripts for reproducing
# the results in Section 4 (Application to Hippocampus Segmentation) of 
# the manuscript. 
#
# Please note the runtimes in the comments to give you a sense of how long these
# scripts take. Those are the approximate runtimes on a Windows 10 machine with
# Intel Xeon 4.1 GHz CPU and 64 GB RAM.
#
################################################################################

rm(list= ls())

# Single Brain Analysis

# Set up and run the model on a single brain using gray matter as a covariate
source("SingleBrain_MCMC.R")  # Runtime: ~17 hours

# Set up and run the model on the same brain as above, but without gray matter
# as a covariate.
source("SingleBrain_NoGM_MCMC.R")  # Runtime: Similar to above

# Read in the results and summarize, including producing the associated 
# figures.
source("SingleBrainImages.R")


#######################

# Aggregated Analysis over six AD patients

# Set up and loop over all of the remaining brain images, running MCMC on each
source("Automated_ADBrains_MCMC.R")  # Runtime: ~4 days

# Load all of the results and produce the associated figures
source("AggregateBrainImages.R")

# Quit

# Record session info
writeLines(capture.output(sessionInfo()), "sessionInfo.txt")

q(save= "no")
