#
# GoodSegSimulations.R
#
# This reproduces the simulated atlases from the "quality atlas" simulation
# study in the manuscript.
#
#-------------------------------------------------------------------------------

rm(list= ls())

require(lattice)
require(gridExtra)

# Directories for storing results and images
img.dir <- "Images\\"  # To store images
res.dir <- "SimData\\"  # Directory for simulated data

#-------------------------------------------------------------------------------

# Create the simulated data
sim.dat<- matrix(rep(0, times= 2500), nrow= 50, ncol= 50)  # Truth
sim.dat[20:30, 10:17] <- 1
sim.dat[24, c(9,18)] <- 1
sim.dat[25, c(8:9, 18:9)] <- 1
sim.dat[31, 11:16] <- 1
sim.dat[32, 12:15] <- 1
sim.dat[33, 13:14] <- 1


# Translation 1
trans.seg <- matrix(rep(0, times= 2500), nrow= 50, ncol= 50)
trans.seg[(20+2):(30+2), 10:17] <- 1
trans.seg[24+2, c(9,18)] <- 1
trans.seg[25+2, c(8:9, 18:9)] <- 1
trans.seg[31+2, 11:16] <- 1
trans.seg[32+2, 12:15] <- 1
trans.seg[33+2, 13:14] <- 1

# Translation 2 
dil.seg <- matrix(rep(0, times= 2500), nrow= 50, ncol= 50)  # Variable names
  # are artifacts from older version of the code.
dil.seg[(20-2):(30-2), 10:17] <- 1
dil.seg[24-2, c(9,18)] <- 1
dil.seg[25-2, c(8:9, 18:9)] <- 1
dil.seg[31-2, 11:16] <- 1
dil.seg[32-2, 12:15] <- 1
dil.seg[33-2, 13:14] <- 1

# Translation 3
con.seg <- matrix(rep(0, times= 2500), nrow= 50, ncol= 50)
con.seg[(20):(30), (10+2):(17+2)] <- 1
con.seg[24, c(9+2,18+2)] <- 1
con.seg[25, c((8+2):(9+2), (18+2):(9+2))] <- 1
con.seg[31, (11+2):(16+2)] <- 1
con.seg[32, (12+2):(15+2)] <- 1
con.seg[33, (13+2):(14+2)] <- 1

# Translation 4
rot.seg <- matrix(rep(0, times= 2500), nrow= 50, ncol= 50)
rot.seg[(20):(30), (10-2):(17-2)] <- 1
rot.seg[24, c(9-2,18-2)] <- 1
rot.seg[25, c((8-2):(9-2), (18-2):(9-2))] <- 1
rot.seg[31, (11-2):(16-2)] <- 1
rot.seg[32, (12-2):(15-2)] <- 1
rot.seg[33, (13-2):(14-2)] <- 1

#-------------------------------------------------------------------------------

# This code reproduces the left and right plots in Figure 2 of the manuscript

# True segmentation
pdf(paste0(img.dir, "TrueHydrant.pdf"))
levelplot(t(sim.dat), col.regions= gray(0:32/32), xlab= "", ylab= "", 
          scales= list(draw= F), colorkey= FALSE)
dev.off()

# Create a 4x4 plot of the "offset" segmentations
pdf(paste0(img.dir, "OffsetHydrants.pdf"))
plot1 <- levelplot(t(trans.seg), col.regions= gray(0:32/32), xlab= "", ylab= "", 
                   scales= list(draw= F), colorkey= FALSE)

plot2 <- levelplot(t(dil.seg), col.regions= gray(0:32/32), xlab= "", ylab= "", 
                   scales= list(draw= F), colorkey= FALSE)

plot3 <- levelplot(t(con.seg), col.regions= gray(0:32/32), xlab= "", ylab= "", 
                   scales= list(draw= F), colorkey= FALSE)

plot4 <- levelplot(t(rot.seg), col.regions= gray(0:32/32), xlab= "", ylab= "", 
                   scales= list(draw= F), colorkey= FALSE)
grid.arrange(plot1, plot2, plot3, plot4)
dev.off()

#-------------------------------------------------------------------------------

# Write the simulated data to file.
save("con.seg", "dil.seg", "rot.seg", "sim.dat", "trans.seg",
     file= paste0(res.dir, "GoodSegsSimData.Rdata"))