#
# GoodSeg_Images.R
#
# This reproduces the Figures associated with the "quality atlases" simulation
# study in the manuscript. 
################################################################################

rm(list= ls())

require(lattice)
require(gridExtra)


mcmc.out.dir <- "Results\\"  # Where the MCMC output is located
img.dir <- "Images\\"  # To store images


################################################################################
# Load the results that had the SDL covariate

load(paste0(mcmc.out.dir, "GoodSeg_SDL_MCMC_results.Rdata"))

# Discarding first half of the chain
keep <- (length(lamj.SeR.MCMC[[1]])/2 + 1):length(lamj.SeR.MCMC[[1]])

# Get the posterior probability map and threshold
prb.mean <- apply(probs.MCMC[keep, ], 2, mean)


prb.mn.img <- levelplot(t(matrix(prb.mean, nrow= P1, ncol= P2)), 
                    col.regions= gray(0:32/32),
                    scales= list(draw= FALSE), 
                    at= seq(0, 1, length= 25), xlab= "", ylab= "")


prb.thresh.img <- levelplot(t(matrix(prb.mean > 0.7, nrow= P1, ncol= P2)), 
                      col.regions= gray(0:32/32),
                      scales= list(draw= FALSE), 
                      at= seq(0, 1, length= 25), xlab= "", ylab= "")


################################################################################

# Get the intercept-only results and repeat
load(paste0(mcmc.out.dir, "GoodSeg_IntOnly_MCMC_results.Rdata"))

keep <- (length(lamj.SeR.MCMC[[1]])/2 + 1):length(lamj.SeR.MCMC[[1]])


prb.mean <- apply(probs.MCMC[keep, ], 2, mean)


prb.io.img <- levelplot(t(matrix(prb.mean, nrow= P1, ncol= P2)), 
                        col.regions= gray(0:32/32),
                        scales= list(draw= FALSE), 
                        at= seq(0, 1, length= 25), xlab= "", ylab= "")


prb.io.thresh.img <- levelplot(t(matrix(prb.mean > 0.7, nrow= P1, ncol= P2)), 
                            col.regions= gray(0:32/32),
                            scales= list(draw= FALSE), 
                            at= seq(0, 1, length= 25), xlab= "", ylab= "")

# This produces Figure 3 in the manuscript
pdf(paste0(img.dir, "GoodSegResultsPLot.pdf"))
grid.arrange(prb.mn.img, prb.thresh.img, prb.io.img, prb.io.thresh.img)
dev.off()
