# @file pad.R
# @author Kristin Linn
# @author 2-9-16
# @brief Third step in the ADNI data preprocessing pipeline

library (parallel)
library (methods)
library(fslr)
library(neurobase)
options(fsl.path='/appl/fsl-6.0.3')

# Run subjects in parallel
args = commandArgs(trailingOnly=TRUE)
jobInd = as.numeric(args[1])

# Directories
rootdir = '/project/hippocampus_segmentation'
atlasdir = file.path(rootdir, 'atlases')
labeldir = file.path(rootdir, 'labels')
system(paste0('mkdir ', labeldir))
opdir = file.path(rootdir, 'output')
system(paste0('mkdir ', opdir))

# NOTE: We will use the $LSB_JOBINDEX atlas as our target
atlases = list.files(atlasdir)
system(paste0('mkdir ', file.path(opdir, atlases[jobInd])))
targetdir = file.path(opdir, atlases[jobInd])
fixedFile = file.path(atlasdir, atlases[jobInd])

# Pad up to these dimensions
maxDims = c(200,320,290)

# Read in images, pad both the T1 and skull stripped T1
fixedT1 = readnii(file.path(fixedFile, 'N4_T1.nii.gz'))
strippedT1 = readnii(file.path(fixedFile, 'N4_T1_brain.nii.gz'))
fixedDim = dim(fixedT1)
# Pad this much on each side
pad = (maxDims - fixedDim)/2
# Pad with zeros
fixedPad = zero_pad(fixedT1, pad)
writenii(fixedPad, filename=file.path(fixedFile, 'PAD_N4_T1'))
strippedPad = zero_pad(strippedT1, pad)
strippedPad = copyNIfTIHeader(fixedPad, strippedPad)
writenii(strippedPad, filename=file.path(fixedFile, 'PAD_N4_T1_brain'))

# Find slices that have brain
z = apply(strippedPad, 3, function(x) all(x<=0))
zinds = which(z==FALSE)
# Buffer around those slices
zinds = c((zinds[1]-10):(zinds[1]-1), zinds, (zinds[length(zinds)]+1):(zinds[length(zinds)]+10))
# Anything outside of brain and buffer, set to zero
toZero = !(1:dim(fixedPad)[3])%in%zinds
fixedPad@.Data[,,toZero] = 0
writenii(fixedPad, filename=file.path(fixedFile, 'NONECK_PAD_N4_T1'))

# Pad the manual segmentations
L = readnii(file.path(fixedFile, paste0(atlases[jobInd], '_L.nii.gz')))
dimL = (maxDims - dim(L))/2
padL = zero_pad(L, dimL)
writenii(padL, file.path(fixedFile, paste0(atlases[jobInd], '_L_PAD.nii.gz')))

R = readnii(file.path(fixedFile, paste0(atlases[jobInd], '_R.nii.gz')))
dimR = (maxDims - dim(R))/2
padR = zero_pad(R, dimR)
writenii(padR, file.path(fixedFile, paste0(atlases[jobInd], '_R_PAD.nii.gz')))




################################################
if(FALSE){
> sessionInfo()
\R version 3.2.5 (2016-04-14)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: CentOS Linux 7 (Core)

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=en_US.UTF-8    
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
[1] fslr_2.22.0      neurobase_1.19.1 oro.nifti_0.9.1 

loaded via a namespace (and not attached):
 [1] tools_3.2.5        abind_1.4-5        Rcpp_0.12.14       R.methodsS3_1.7.1 
 [5] splines_3.2.5      RNifti_0.7.1       R.utils_2.7.0      matrixStats_0.52.2
 [9] bitops_1.0-6       R.oo_1.22.0       
}
