# @file normalize.R
# @author Kristin Linn
# @date 2-10-16
# @brief Fifth step in the ADNI data preprocessing pipeline.

library (parallel)
library (methods)
library(neurobase)
library(WhiteStripe)

# Run subjects in parallel
args = commandArgs(trailingOnly=TRUE)
jobInd = as.numeric(args[1])

# Directories
rootdir = '/project/hippocampus_segmentation'
atlasdir = file.path(rootdir, 'atlases')
opdir = file.path(rootdir, 'output')

# NOTE: We will use the $LSB_JOBINDEX atlas as our target
atlases = list.files(atlasdir)
targetT1 = readnii(file.path(atlasdir, atlases[jobInd], 'PAD_N4_T1_brain.nii.gz'))
wsT1 = whitestripe(targetT1, type="T1", stripped=TRUE)
normT1 = whitestripe_norm(targetT1, wsT1$whitestripe.ind)
writenii(normT1, filename=file.path(atlasdir, atlases[jobInd], 'WS_PAD_N4_T1'))

# Loop over atlases
for(i in 1:11){
    print(i)
    regT1s = list.files(file.path(opdir, atlases[jobInd]), pattern='ATL.nii.gz', full.names=TRUE)[1:11]
    regT1sShort = list.files(file.path(opdir, atlases[jobInd]), pattern='ATL.nii.gz')[1:11]
    # Read in image
    atlasT1 = readnii(regT1s[i])
    atlasT1[atlasT1<30] = 0
    wsT1 = whitestripe(atlasT1, type="T1", stripped=TRUE)
    normT1 = whitestripe_norm(atlasT1, wsT1$whitestripe.ind)
    writenii(normT1, filename=file.path(opdir, atlases[jobInd], paste0('WS_', nii.stub(regT1sShort[i]))))
}





##########################################
if (FALSE){

> sessionInfo()
R version 3.2.5 (2016-04-14)
Platform: x86_64-pc-linux-gnu (64-bit)
Running under: CentOS Linux 7 (Core)

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_US.UTF-8        LC_COLLATE=en_US.UTF-8    
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

attached base packages:
[1] parallel  stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
[1] WhiteStripe_2.2.2 neurobase_1.19.1  oro.nifti_0.9.1  

loaded via a namespace (and not attached):
 [1] Rcpp_0.12.14       lattice_0.20-35    matrixStats_0.52.2 bitops_1.0-6      
 [5] R.methodsS3_1.7.1  grid_3.2.5         nlme_3.1-131       R.oo_1.22.0       
 [9] R.utils_2.7.0      Matrix_1.2-15      splines_3.2.5      tools_3.2.5       
[13] abind_1.4-5        mgcv_1.8-24        RNifti_0.7.1   
}