# Download hippocampal segmentations (.nii files):
# http://www.hippocampal-protocol.net/SOPs/index.php

# Main project folder:
rootdir=/project/hippocampus_segmentation

# Put all pre-processing scripts in a folder called 'code' in the following location:
codedir=$rootdir/code

# Set queue variable for batch jobs:
queue=queue_normal

# Make a local folder called $rootdir/atlases:
mkdir atlases
# Create a subfolder for each subject
mkdir $rootdir/atlases/0016
mkdir $rootdir/atlases/0067
mkdir $rootdir/atlases/0088
mkdir $rootdir/atlases/0172
mkdir $rootdir/atlases/0221
mkdir $rootdir/atlases/0413
mkdir $rootdir/atlases/0419
mkdir $rootdir/atlases/0525
mkdir $rootdir/atlases/0592
mkdir $rootdir/atlases/0754
mkdir $rootdir/atlases/0784
mkdir $rootdir/atlases/1263

# Make a local folder for output called $rootdir/output:
mkdir output
# Create a subfolder for each subject
mkdir $rootdir/output/0016
mkdir $rootdir/output/0067
mkdir $rootdir/output/0088
mkdir $rootdir/output/0172
mkdir $rootdir/output/0221
mkdir $rootdir/output/0413
mkdir $rootdir/output/0419
mkdir $rootdir/output/0525
mkdir $rootdir/output/0592
mkdir $rootdir/output/0754
mkdir $rootdir/output/0784
mkdir $rootdir/output/1263

# Put the segmentation files listed in _segmentation_files.txt in $rootdir/atlases and run the following script (requires FSL; recommend v6.0 or later)
sh $codedir/0_rename_reorient.sh

# Download the baseline MPRAGE for each of the 12 subjects from the ADNI database hosted by LONI: 
# http://adni.loni.usc.edu/data-samples/access-data/
# Convert each one to a .nii.gz file and rename each one as <subjectID>_MPRAGE.nii.gz
# Place each in a corresponding folder called <subjectID> within $rootdir/atlases/


####################
# N4 correction
####################
# Load the following modules
module load python/3.9.2
module load ANTs/2.3.1

python $codedir/1_n4.py 16 $rootdir
python $codedir/1_n4.py 67 $rootdir
python $codedir/1_n4.py 88 $rootdir
python $codedir/1_n4.py 172 $rootdir
python $codedir/1_n4.py 221 $rootdir
python $codedir/1_n4.py 413 $rootdir
python $codedir/1_n4.py 419 $rootdir
python $codedir/1_n4.py 525 $rootdir
python $codedir/1_n4.py 592 $rootdir
python $codedir/1_n4.py 754 $rootdir
python $codedir/1_n4.py 784 $rootdir
python $codedir/1_n4.py 1263 $rootdir

#############################
# MASS skull stripping
#############################
# Load the following module
module load MASS/1.1.0

bsub -q $queue -J "mass[16,67,88,172,221,413,419,525,592,754,784,1263]" < 2_runMass.sh

#################################
# Pad images before registration
#################################
# Load the following modules
module load R/3.2.5
module load fsl/6.0.3

bsub -q $queue -J "pad[16,67,88,172,221,413,419,525,592,754,784,1263]" < 3_pad.sh

#################################
# Registrations
#################################
# Load the following modules
module load R/3.2.5
module load ANTs/2.3.1

bsub -q $queue -n 4 -J "reg[1-12]" < 4_registration.sh

###################################################
# Intensity normalization with WhiteStripe
###################################################
# Load the following modules
module load R/3.2.5

bsub -q $queue -J "ws[1-12]" < 5_whiteStripe.sh

#################################
# Tissue segmentation
#################################
# Load the following modules
module load R/3.2.5
module load ANTs/2.3.1

bsub -q $queue -J "tissue[1-12]" < 6_tissueSegmentattion.sh

#################################
# Set up new directories for JLF
#################################
mkdir $rootdir/jlf_by_group
mkdir $rootdir/jlf_by_group/t1s_ad
mkdir $rootdir/jlf_by_group/t1s_cn
mkdir $rootdir/jlf_by_group/jlf_cn_to_ad

# Copy images into appropriate folders by diagnosis
cp $rootdir/atlases/0088/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/0088_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0221/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/0221_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0592/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/0592_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0754/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/0754_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0784/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/0784_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/1263/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_ad/1263_WS_PAD_N4_T1.nii.gz

cp $rootdir/atlases/0016/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0016_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0067/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0067_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0172/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0172_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0413/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0413_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0419/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0419_WS_PAD_N4_T1.nii.gz
cp $rootdir/atlases/0525/WS_PAD_N4_T1.nii.gz $rootdir/jlf_by_group/t1s_cn/0525_WS_PAD_N4_T1.nii.gz


#################################
# Joint label fusion
#################################
# Load the following module:
module load ANTs2/2.2.0-111

bsub -q $queue -J "jlf[1-6]" < 7_jlf_cn_to_ad.sh


#################################################
# Extract 3D subset images around hippocampus
#################################################
# Load the following module:
module load R/3.2.5

bsub -q $queue -n 12 < 8_subset_images.sh



